c%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
c
c Element: a subroutine for calculating atomic masses and enthalpy functions.
c Copyright (C) 2009 John R. Barker
c
c John R. Barker
c jrbarker@umich.edu
c University of Michigan
c Ann Arbor, MI 48109-2143
c (734) 763 6239
c
c This program is free software; you can redistribute it and/or
c modify it under the terms of the GNU General Public License (version 2)
c as published by the Free Software Foundation.
c
c This program is distributed in the hope that it will be useful, 
c but WITHOUT ANY WARRANTY; without even the implied warranty of
c MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
c GNU General Public License for more details.
c
c See the 'ReadMe' file for a copy of the GNU General Public License,
c or contact:
c
c Free Software Foundation, Inc.
c 59 Temple Place - Suite 330
c Boston, MA 02111-1307, USA.
c
c%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

      SUBROUTINE element( ATYPE , MASS , Hfxn )
      
      DOUBLE PRECISION MASS , Hfxn , R
      CHARACTER ATYPE*6
      SAVE
c
c	MASS (atomic mass units) from NIST / JANAF 1998
c         Hfxn = [H(298.15) - H(0)]/R per atom   [NIST / JANAF]
c
      R = 8.314472D+00

         IF ( ATYPE.EQ.'C' ) THEN
            MASS = 12.011D+00
            Hfxn = 1.051/R
         ELSEIF ( ATYPE.EQ.'C12' ) THEN
            MASS = 12.0D+00
            Hfxn = 1.051 / R                ! assumed to be the same as "C"
         ELSEIF ( ATYPE.EQ.'C13' ) THEN
            MASS = 13.003355D+00
            Hfxn = 1.051 / R                ! assumed to be the same as "C"
         ELSEIF ( ATYPE.EQ.'C14' ) THEN
            MASS = 14.003242D+00
            Hfxn = 1.051 / R                ! assumed to be the same as "C"
         ELSEIF ( ATYPE.EQ.'C16' ) THEN
            MASS = 16.0147D+00
            Hfxn = 1.051 / R                ! assumed to be the same as "C"
         ELSEIF ( ATYPE.EQ.'H' ) THEN
            MASS = 1.00794D+00
            Hfxn = 8.467 / (2.0*R)
         ELSEIF ( ATYPE.EQ.'H1' ) THEN
            MASS = 1.007825D+00
            Hfxn = 8.467 / (2.0*R)          ! assumed to be the same as "H"
         ELSEIF ( ATYPE.EQ.'D' ) THEN
            MASS = 2.014102D+00
            Hfxn = 8.56 / (2.0*R)           ! calculated by using parameters found in NIST web-book
         ELSEIF ( ATYPE.EQ.'T' ) THEN
            MASS = 3.016049D+00
            Hfxn = 8.60 / (2.0*R)           ! calculated by using parameters found in NIST web-book
         ELSEIF ( ATYPE.EQ.'O' ) THEN
            MASS = 15.9994D+00
            Hfxn = 8.683 / (2.0*R)
         ELSEIF ( ATYPE.EQ.'O16' ) THEN
            MASS = 15.994915D+00
            Hfxn = 8.68 / (2.0*R)    ! Calculated using rot and vib constants from Edwards et al., J. Raman Spectrosc., 10, 60-63 (1981)
         ELSEIF ( ATYPE.EQ.'O17' ) THEN
            MASS = 16.9991315D+00
            Hfxn = 8.68 / (2.0*R)    ! Calculated using rot and vib constants from Edwards et al., J. Raman Spectrosc., 10, 60-63 (1981)
         ELSEIF ( ATYPE.EQ.'O18' ) THEN
            MASS = 17.999160D+00
            Hfxn = 8.69 / (2.0*R)    ! Calculated using rot and vib constants from Edwards et al., J. Raman Spectrosc., 10, 60-63 (1981)
         ELSEIF ( ATYPE.EQ.'N' ) THEN
            MASS = 14.00674D+00
            Hfxn = 8.670 / (2.0*R)
         ELSEIF ( ATYPE.EQ.'N14' ) THEN
            MASS = 14.003074D+00
            Hfxn = 8.670 / (2.0*R)    ! Calculated using rot and vib constants from Gilson et al., J. Raman Spectrosc. 9, 361-368 (1980) & Bendtsen, J. Raman Spectrosc. 2, 133-145 (1974)
         ELSEIF ( ATYPE.EQ.'N15' ) THEN
            MASS = 15.00010897D+00
            Hfxn = 8.670 / (2.0*R)    ! Calculated using rot and vib constants from Gilson et al., J. Raman Spectrosc. 9, 361-368 (1980) & Bendtsen, J. Raman Spectrosc. 2, 133-145 (1974)
         ELSEIF ( ATYPE.EQ.'F' ) THEN
            MASS = 18.998403D+00
            Hfxn = 8.825 / (2.0*R)
         ELSEIF ( ATYPE.EQ.'Cl' ) THEN
            MASS = 35.453D+00
            Hfxn = 9.181 / (2.0*R)
         ELSEIF ( ATYPE.EQ.'Cl35' ) THEN
            MASS = 34.96885271D+00
            Hfxn = 9.17 / (2.0*R)      ! Calculated using rot and vib constants from Bermejo et al., J. Mol. Spectrosc. 212, 186-193 (2002)
         ELSEIF ( ATYPE.EQ.'Cl37' ) THEN
            MASS = 36.9659D+00
            Hfxn = 9.16 / (2.0*R)      ! Calculated using rot and vib constants from Bermejo et al., J. Mol. Spectrosc. 212, 186-193 (2002)
         ELSEIF ( ATYPE.EQ.'Br' ) THEN
            MASS = 79.904D+00
            Hfxn = 24.509 / (2.0*R)
         ELSEIF ( ATYPE.EQ.'Br79' ) THEN
            MASS = 78.918338D+00
            Hfxn = 24.509 / (2.0*R)    ! assumed to be the same as "Br"
         ELSEIF ( ATYPE.EQ.'Br81' ) THEN
            MASS = 80.916291D+00
            Hfxn = 24.509 / (2.0*R)    ! assumed to be the same as "Br"
         ELSEIF ( ATYPE.EQ.'I ' ) THEN
            MASS = 126.9045D+00
            Hfxn = 13.198 / (2.0*R)
         ELSEIF ( ATYPE.EQ.'S' ) THEN
            MASS = 32.06D+00
            Hfxn = 4.412 / R
         ELSEIF ( ATYPE.EQ.'S32' ) THEN
            MASS = 31.9720707D+00
            Hfxn = 4.412 / R             ! assumed to be the same as "S"
         ELSEIF ( ATYPE.EQ.'S34' ) THEN
            MASS = 33.9678668D+00
            Hfxn = 4.412 / R             ! assumed to be the same as "S"
         ELSEIF ( ATYPE.EQ.'P' ) THEN
            MASS = 30.97376D+00
            Hfxn = 5.360 / R
         ELSEIF ( ATYPE.EQ.'Si' ) THEN
            MASS = 28.0855D+00
            Hfxn = 3.218/ R
         ELSEIF ( ATYPE.EQ.'B' ) THEN
            MASS = 10.81D+00
            Hfxn = 1.214/ R
         ELSEIF ( ATYPE.EQ.'Li' ) THEN
            MASS = 6.941D+00
            Hfxn = 4.622/ R
         ELSEIF ( ATYPE.EQ.'Hg' ) THEN
            MASS = 200.59D+00
            Hfxn = 9.343/ R
         ELSEIF ( ATYPE.EQ.'K' ) THEN
            MASS = 39.0983D+00
            Hfxn = 7.082/ R
         ELSEIF ( ATYPE.EQ.'Rb' ) THEN
            MASS = 85.4678D+00
            Hfxn = 7.490/ R
         ELSEIF ( ATYPE.EQ.'Se' ) THEN
            MASS = 78.96D+00
            Hfxn = 5.519/ R
         ELSEIF ( ATYPE.EQ.'Na' ) THEN
            MASS = 22.98977D+00
            Hfxn = 6.447/ R
         ELSEIF ( ATYPE.EQ.'Te' ) THEN
            MASS = 127.60D+00
            Hfxn = 6.121/ R
         ELSEIF ( ATYPE.EQ.'Sn' ) THEN
            MASS = 118.69D+00
            Hfxn = 6.297/ R
         ELSEIF ( ATYPE.EQ.'Si' ) THEN
            MASS = 28.0855D+00
            Hfxn = 3.218 / R
         ELSEIF ( ATYPE.EQ.'Si29' ) THEN
            MASS = 28.98D+00
            Hfxn = 3.218 / R              ! assumed to be the same as Si
         ELSEIF ( ATYPE.EQ.'Si30' ) THEN
            MASS = 29.97D+00
            Hfxn = 3.218 / R              ! assumed to be the same as Si
         ELSEIF ( ATYPE.EQ.'He' ) THEN
            MASS = 4.00260D+00
            Hfxn = 6.197 / R
         ELSEIF ( ATYPE.EQ.'Ne' ) THEN
            MASS = 20.179D+00
            Hfxn = 6.197 / R
         ELSEIF ( ATYPE.EQ.'Ar' ) THEN
            MASS = 39.948D+00
            Hfxn = 6.197 / R
         ELSEIF ( ATYPE.EQ.'Kr' ) THEN
            MASS = 83.80D+00
            Hfxn = 6.197 / R
         ELSEIF ( ATYPE.EQ.'Xe' ) THEN
            MASS = 131.29D+00
            Hfxn = 6.197 / R
         ELSE
            STOP 'Element not recognized in subroutine element.f'
         ENDIF

      RETURN
      END
      
      
