      SUBROUTINE RateArray(T)
 
c%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
c
c MultiWell: a code for chemical kinetics calculations.
c Copyright (C) 2008 John R. Barker
c
c John R. Barker
c jrbarker@umich.edu
c University of Michigan
c Ann Arbor, MI 48109-2143
c (734) 763 6239
c
c This program is free software; you can redistribute it and/or
c modify it under the terms of the GNU General Public License (version 2)
c as published by the Free Software Foundation.
c
c This program is distributed in the hope that it will be useful,
c but WITHOUT ANY WARRANTY; without even the implied warranty of
c MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
c GNU General Public License for more details.
c
c See the 'ReadMe' file for a copy of the GNU General Public License,
c or contact:
c
c Free Software Foundation, Inc.
c 59 Temple Place - Suite 330
c Boston, MA 02111-1307, USA.
c
c%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
c
c	k(E) calculated and stored in double array 'Rate'.  Note that
c	reverse rxns are calculated with same sums of states as
c	forward rxns.
c
c	T	= translational temperature
c	Mol	= index of reactant molecule
c	Nchan	= number of channels originating from Mol
c	Jread	= 0  use inverse Laplace transform method for channel
c		= 1  read sums of states for channel from external file
c		= 2  read k(E) for this channel from external file
c	Jto	= index of product molecule
c	Jrev	= 0 for neglecting the reverse reaction
c		= 1 for calculating reverse rxn rate; after calculation,
c			Jrev=1 is changed to Jrev=2
c	Afact	= A-factor for reaction (units: s-1) [for ILT method]
c	Eact	= activation energy (units: cm-1) [for ILT method]
c
c	Note that File name and path in OPEN statements may need revision
c		for non-Macintosh
c
c***********************************************************************
c
c 10/03  v1.3.3  (JP) trimmed defined-length character strings with lenstr.
c 01/02  v1.2.0  -New Feature: can optionally choose to apply centrifugal
c                 corrections for any choice of model. Thus can apply them
c                 even when using Inverse Laplace Transform form of k(E).
c                 NOTE: this new feature affects the data file format.
c 11/01  v1.1.4  -Bug Fix: previous version applied centrifugal correction 
c                 inconsistently when calculating Arrhenius parameters 
c                 (k(inf) was correct, however).
c 09/01  v1.1.2  -Revised centrigfugal corrections to k(E)'s.
c                 See Robinson & Holbrook (1972) eq. 4.30 and 4.31.
c 07/00  v1.1    -All k(E)'s now calculated including Path(Mol,i)
c 07/00  v1.1    -For k(E) read from file, can calculate reverse rxn k(E)
c
c***********************************************************************
      IMPLICIT NONE
      INCLUDE 'declare1.inc'
      INTEGER i , j , Mol , JJ , jdum , lenstr
      DOUBLE PRECISION DENVR , E , EE , DD , A , B , TSsum , T , DUM , 
     &                 ER , Test1 , Test2 
      DOUBLE PRECISION psum , DENTS ,absbar, DScrit
      CHARACTER TITLE*100
      SAVE 

      
        DO 100 Mol = 1 , NWells

 
         IF ( Mol .LE. Nwells ) THEN     ! Ensure that Mol has a density of states array
            DO 20 i = 1 , Nchan(Mol)
 
               Path(Mol,i) = (Molsym(Mol)*TSele(Mol,i)*TSopt(Mol,i))
     &                       /(TSsym(Mol,i)*Molele(Mol)*Molopt(Mol))
                          ! Rxn path degeneracy X electronic partition fxn ratio used for all k(E)

               IF ( (NCENT(Mol,i) .EQ. 1) .AND. (MolMom(Mol) .GT. 0.0)  
     &                              .AND. (TSmom(Mol,i) .GT. 0.0) ) THEN
                   Eor(Mol,i) =  Eo(Mol,i)
     &                   + (1.0-TSmom(Mol,i)/MolMom(Mol))*T/hor ! Centrifugal correction
               ELSE
                   Eor(Mol,i) =  Eo(Mol,i)
               ENDIF                     
              

               IF ( Jread(Mol,i).EQ.0 ) THEN            ! Inverse-Laplace-Transform !!!!!!!!!!!!!!!!!!!!!!!!!!!
                   
c                  IF ( NCENT(Mol,i) .EQ.1 )THEN         ! If centrifugal correction, modify A-factor
c                      Afac(Mol,i) = Afac(Mol,i)*MolMom(Mol)/TSmom(Mol,i)
c                  ENDIF                     

                  DO 5 j = 1 , Isize
                     IF ( j.LE.imax1 ) THEN             ! E = energy from top of barrier
                        E = (j-1)*Egrain1
                     ELSE
                        E = (j-imax1-1)*Egrain2
                     ENDIF
                     EE = E + Eor(Mol,i)                ! Includes centrifugal correction
                     IF ( EE .LE. Emax2) THEN           ! calculate k(E) only up to Emax2, since dens is undefined for higher E
                       DD = DENVR(Mol,EE)
                       Rate(Mol,i,j) = Afac(Mol,i)*DENVR(Mol,E)/DD  ! k(E)
                       Rate(Mol,i,j) = LOG(Rate(Mol,i,j))           ! k(E) stored as log
                     ELSE
                       Rate(Mol,i,j) = LOG( 1.e-20 )                ! k(E) stored as log
                     ENDIF
                       
 5                CONTINUE
 
               ELSEIF ( Jread(Mol,i).EQ.1 ) THEN        ! Read sums of states from external file !!!!!!!!!!!!!!!!!!!!!!!!!!
                  OPEN (12,FILE='DensData/'//
     &            TSname(Mol,i)(1:lenstr(TSname(Mol,i)))//'.dens',
     &            STATUS='OLD')                         ! TST sum of states

                  READ (12,99030) dumcut                ! Check to see if file format includes input data summary
                  IF ( dumcut .EQ. cut ) THEN           ! Format starting with v.2008.1
                    dumcut = 'x'
                    DO WHILE (dumcut .NE. cut)
                      READ (12,99030) dumcut
                    END DO
                 ELSE
                    BACKSPACE 12                        ! If format from prior to v.2008.1
                 ENDIF
99030 FORMAT (A46)

                  READ (12,*) TITLE
                  READ (12,*) TITLE
                  READ (12 , * )  A , JJ , B , j , DUM
                  READ (12,*) TITLE
                  Test1 = ABS(A-Egrain1)/1.D-06
                  Test2 = ABS(B-Emax2)/1.D-06
                  IF ( Test1.LT.1.0 .AND. JJ.EQ.imax1 .AND. ! Test for proper array bounds, etc.
     &                 Test2.LT.1.0 .AND. j.EQ.Isize ) THEN

                          DScrit=0.00001d0/Egrain1     ! If the density of states is less than DScrit
                                                       ! then k(E) is set to zero for the tunneling and
                                                       ! non-tunneling cases below 

                          absbar=HMol(Mol)+Eor(Mol,i)   ! absolute energy of barrier needed to determine
                                                        ! back reaction barrier

                          V1(Mol,i)=absbar-HMol(Jto(Mol,i))   ! HMol(Jto(Mol,i)) is the enthalpy of the product


                          if(itun(Mol,i).eq.1)then     ! check to make sure the back reaction barrier is
                                                       ! greater than zero, which must be the case if tunneling
                                                       ! is to be considered
                            if(V1(Mol,i).lt.0)then
                              write(6,99005)Jto(Mol,i),Mol
                              itun(Mol,i)=0
                            end if
                          end if

                          if(itun(Mol,i).eq.1)then   ! tunneling condition


                            write(*,99003) Mol        ! Entering tunneling routine write statement

                            CALL DensArrayTS(Mol,i)   ! set up the densTS array so that the density of states
                                                      ! of the transition state can be interpolated later
                            do j=1,Isize+imax1        ! loop over energies for which k(E) will be calculated

                              IF ( j.LE.imax1*2 ) THEN                
                                E = (j-1)*Egrain1               
                                EE=Eor(Mol,i)-((imax1-1)*Egrain1)+E  ! Includes centrifugal correction
                              ELSE 
                                E = (j-imax1*2-1)*Egrain2
                                EE=Eor(Mol,i)+E  ! Includes centrifugal correction; ensures 2nd part
                              ENDIF              ! of double array starts at 0 cm-1 instead of below the barrier


                              if((Jrev(Mol,Jto(Mol,i))).eq.1)then  ! if the reverse rxn from well Mol to product Jto(Mol,i)
                                                                   ! is considered than store the density of states of the 
                                                                   ! product calculated for the forward rxn in TSdensBK  and 
                                                                   ! use this quantity to calculate the reverse rxn rate 

                                iset(Mol)=Jto(Mol,i)           ! the reverse rxn will have iset(Mol) as the well and 
                                iset2(Mol)=Mol                 ! iset2(Mol) as the product

                              else if((Mol.eq.iset(Mol)).and.    
     +                              (Jto(Mol,i).eq.iset2(Mol)))then

                                if(TSdensBK(iset2(Mol),j).lt.1e-30)then
                                  TRate(Mol,i,j)=-70.0d0       
                                  goto 19                      
                                end if

                                if(DENVR(Mol,EE).lt.DScrit)then
                                  TRate(Mol,i,j)=-70.0d0
                                  goto 19
                                end if

                                IF ( EE .LE. Emax2 ) THEN               ! If molecular energy is not too high, claculate k(E)
                                TRate(Mol,i,j)=TSdensBK(iset2(Mol),j)*
     &                                  clight*Path(Mol,i)/DENVR(Mol,EE)!    k(E) with tunneling correction
                                TRate(Mol,i,j) = LOG(TRate(Mol,i,j))    !    k(E) with tunneling correction stored as log
                                goto 19
                                ELSE
                                 TRate(Mol,i,j) = -70.0                 ! Do not calculate k(E) if molecular energy >Emax2
                                ENDIF

                              end if

                            
                              CALL ECKART(Mol,i,EE,psum,j)  ! calculate tunneling correction using 
                                                            ! unsymmetrical Eckart potential


                              if((Jrev(Mol,Jto(Mol,i))).eq.1)then   ! if the reverse rxn  Jto(Mol,i)-->Mol is considered 
                                TSdensBK(Mol,j)=psum                ! save the denisty of states of the TS for the forward
                              end if                                ! rxn and use them to calculate the reverse rxn rate, i.e.
                                                                    ! don't perform the calculation twice

                              if(psum.lt.1e-30)then        ! this if statement is necessary because if the sum of 
                                TRate(Mol,i,j)=-70.0d0     ! is zero taking LOG(TRate(Mol,i,j) below results in NAN 
                                goto 19                    ! this circumvents that problem
                              end if

                              if(DENVR(Mol,EE).lt.DScrit)then
                                TRate(Mol,i,j)=-70.0d0
                                goto 19
                              end if

                              IF ( EE .LE. Emax2 ) THEN                 ! If molecular energy is not too high, claculate k(E)
                              TRate(Mol,i,j) = psum*clight*Path(Mol,i)
     &                                       /DENVR(Mol,EE)             ! k(E) with tunneling correction
                              TRate(Mol,i,j) = LOG(TRate(Mol,i,j))      ! k(E) with tunneling correction stored as log
                              ELSE
                              TRate(Mol,i,j) = -70.0                    ! Do not calculate k(E) if molecular energy >Emax2
                              ENDIF

19                         CONTINUE
                         end do

                           write(*,99004)

                       else

                          DO 6 j = 1 , Isize                        ! **** NO TUNNELING *************************************
                            READ (12,*) jdum , A , B , TSsum        ! Read sum of states  (here, A and B are dummy variables)
                            IF ( j.LE.imax1 ) THEN                  ! E = active energy from top of barrier
                              E = (j-1)*Egrain1
                            ELSE
                              E = (j-imax1-1)*Egrain2
                            ENDIF
                            EE = E + Eor(Mol,i)                     ! Includes centrifugal correction

                            IF ( EE .LE. Emax2) THEN           ! calculate k(E) only up to Emax2, since dens is undefined for higher E
                              DD = DENVR(Mol,EE)
                              if ( DD .lt. DScrit ) then
                                Rate(Mol,i,j)= LOG( 1.d-20 )   ! the density of states of the reactant is less
                                goto 6                         ! than DScrit, set the rate constant equal to zero.
                              end if
                              DD = TSsum/DD 
                              Rate(Mol,i,j) = clight*DD*Path(Mol,i)     ! k(E) w/o tunneling correction
                              Rate(Mol,i,j) = LOG(Rate(Mol,i,j)+1.e-20) ! k(E) w/o tunneling correction stored as log
                            ELSE
                              Rate(Mol,i,j) = LOG( 1.d-20 )             ! k(E) w/o tunneling correction stored as log
                            ENDIF
 6                       CONTINUE
                       end if

                  ELSE                               ! If grain or energy limit does not match
                    WRITE (KSTD,99002) TSname(Mol,i)
                    WRITE (KOUT,99002) TSname(Mol,i)
                    STOP
                  ENDIF
                  CLOSE (12)
 
               ELSEIF ( Jread(Mol,i).EQ.2 ) THEN        ! Read k(E)'s (not including path degeneracy) from external file !!!!!!!!!!!!!!!!!!!!!!!!!!!
                  OPEN (12,FILE='DensData/'//
     &            TSname(Mol,i)(1:lenstr(TSname(Mol,i)))//'.rke',
     &            STATUS='OLD')                   ! k(E)'s
                  READ (12,*) TITLE
                  READ (12,*) TITLE
                  READ (12 , * )  A , JJ , B , j , DUM
                  READ (12,*) TITLE
                  Test1 = ABS(A-Egrain1)/1.D-06
                  Test2 = ABS(B-Emax2)/1.D-06
                  IF ( Test1.LT.1.0 .AND. JJ.EQ.imax1 .AND. 
     &                 Test2.LT.1.0 .AND. j.EQ.Isize ) THEN     ! Test for proper array bounds, etc.
                     DO 8 j = 1 , Isize
                        READ (12,*) jdum , A , B , Rate(Mol,i,j)    ! Read k(E)'s
                        IF(Afac(Mol,i).lt.0) Rate(Mol,i,j)=Rate(Mol,i,j)
     &                                                * ABS(Afac(Mol,i))
                        IF ( Rate(Mol,i,j).GT.1.D-20 ) THEN
                           Rate(Mol,i,j) = LOG(Rate(Mol,i,j))       ! k(E) stored as log
                        ELSE
                           Rate(Mol,i,j) = LOG(1.D-20)              ! k(E) stored as log
                        ENDIF
 8                   CONTINUE
                  ELSE                  ! If grain or energy limit does not match
                     WRITE (KSTD,99002) TSname(Mol,i)
                     WRITE (KOUT,99002) TSname(Mol,i)
                     STOP
                  ENDIF
                  CLOSE (12)
 
               ELSEIF ( Jread(Mol,i).EQ.-2 ) THEN       ! Read k(E)'s (not including path degeneracy) for REVERSE rxn !!!!!!!!!!!!!!!!!!!!!!!!!!!
                  OPEN (12,FILE='DensData/'//
     &            TSname(Mol,i)(1:lenstr(TSname(Mol,i)))//'.rke',
     &            STATUS='OLD')                   ! k(E)'s for REVERSE rxn
                  READ (12,*) TITLE
                  READ (12,*) TITLE
                  READ (12 , * )  A , JJ , B , j , DUM
                  READ (12,*) TITLE
                  Test1 = ABS(A-Egrain1)/1.D-06
                  Test2 = ABS(B-Emax2)/1.D-06
                  IF ( Test1.LT.1.0 .AND. JJ.EQ.imax1 .AND. 
     &                 Test2.LT.1.0 .AND. j.EQ.Isize ) THEN
                                                ! Test for proper array bounds, etc.
                     DO 10 j = 1 , Isize
                        READ (12,*) jdum , A , B , Rate(Mol,i,j)
                                                                ! Read k(E)'s (not including path degeneracy) for REVERSE reaction
 
                        IF ( j.LE.imax1 ) THEN                  ! E = energy from top of barrier
                           E = (j-1)*Egrain1                    ! Energy in forward direction
                        ELSE
                           E = (j-imax1-1)*Egrain2              ! Energy in forward direction
                        ENDIF
                        E = E + Eor(Mol,i)                      ! With rotational correction
                        ER = E - (HMol(Jto(Mol,i))-HMol(Mol))   ! Energy in reverse direction
                        DD = DENVR(Jto(Mol,i),ER)/DENVR(Mol,E)  ! Density of states ratio
                        Rate(Mol,i,j) = Rate(Mol,i,j)*DD*Path(Mol,i)
                                                                ! k(E) in forward direction
                        IF ( Rate(Mol,i,j).GT.1.D-20 ) THEN
                           Rate(Mol,i,j) = LOG(Rate(Mol,i,j))
                                                        ! k(E) stored as log
                        ELSE
                           Rate(Mol,i,j) = LOG(1.D-20)  ! k(E) stored as log
                        ENDIF

 10                  CONTINUE
                  ELSE                  ! If grain or energy limit does not match
                     WRITE (KSTD,99002) TSname(Mol,i)
                     WRITE (KOUT,99002) TSname(Mol,i)
                     STOP
                  ENDIF
                  CLOSE (12)
 
               ENDIF
 20         CONTINUE
         ENDIF

 100    CONTINUE
 
        RETURN
 
99001   FORMAT (A100)
99002   FORMAT (/'Energy grain or energy limit does not match: ',
     &        A10/'****** Run Terminated *******')
99003   FORMAT ('Entering Tunneling Subroutine: Molecule #',I2)
99004   FORMAT ('Leaving Tunneling Subroutine')
99005   FORMAT (/'The reaction barrier from product',i3,' to well', i3,
     &          /' is less than the enthalpy of this product.',
     &   /'Calculations will proceed as if tunneling were not invoked.')
 
        END
